@@ -24,8 +24,8 @@
  * 桼ѥ桼
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.19 $
- * $Date: 2012/09/21 06:11:07 $
+ * $Revision: 1.20 $
+ * $Date: 2013/07/23 06:45:20 $
  **********************************************************/
 include_once("../../initial");
 include_once("lib/dglibldap");
@@ -68,6 +68,8 @@ function check_user_data($mail, $passwd, $repasswd, $trans, $save, &$attrs)
     global $user;
     global $ldapdata;
     global $url_data;
+    
+    $enpass = "";
 
     if (isset($ldapdata[0]['mailAlias'][0])) {
         $alias = $ldapdata[0]['mailAlias'][0];
@@ -76,7 +78,8 @@ function check_user_data($mail, $passwd, $repasswd, $trans, $save, &$attrs)
 
     /* ѥϥå */
     if ($passwd != "" || $repasswd != "") {
-        $ret = check_passwd($passwd, MINPASSWD, MAXPASSWD);
+        $ret = check_passwd($passwd, (int)$web_conf["global"]["minpasswordlength"], 
+                            (int)$web_conf["global"]["maxpasswordlength"]);
         if ($ret === FALSE) {
             return FALSE;
         }
@@ -88,7 +91,11 @@ function check_user_data($mail, $passwd, $repasswd, $trans, $save, &$attrs)
         }
 
         /* ѥɤǼ */
-        $attrs['userPassword'] = CRYPT . my_crypt($passwd);
+        $enpass = make_passwd($passwd);
+        if ($enpass === FALSE) {
+            return FALSE;
+        }
+        $attrs['userPassword'] = $enpass;
     }
 
     if ($trans != "") {
@@ -198,6 +205,7 @@ $tag["<<UID>>"] = "";
 $tag["<<TRANSFERADDR>>"] = "";
 $tag["<<SAVEMAILENABLED>>"] = "";
 $tag["<<SAVEMAILDISABLED>>"] = "";
+$tag["<<MAXPASSLEN>>"] = "";
 
 /* ե롢ִեɹåå */
 $ret = user_init();
@@ -345,6 +353,7 @@ $tag["<<UID>>"] = $dispusr;
 $tag["<<TRANSFERADDR>>"] = $trans;
 $tag["<<SAVEMAILENABLED>>"] = $save_mail_check;
 $tag["<<SAVEMAILDISABLED>>"] = $unsave_mail_check;
+$tag["<<MAXPASSLEN>>"] = $web_conf["global"]["maxpasswordlength"];
 
 /* ڡν */
 $ret = display(TMPLFILE, $tag, array(), "", "");
